@@ -2,12 +2,11 @@
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '2.9.0';
+$Git::Hooks::CheckCommit::VERSION = '2.9.1';
 use 5.010;
 use utf8;
 use strict;
 use warnings;
-use Try::Tiny;
 use Git::Hooks;
 use Git::Repository::Log;
 use List::MoreUtils qw/any none/;
@@ -174,23 +173,8 @@ sub _canonical_identity {
     my $cache = $git->cache($PKG);
 
     unless (exists $cache->{canonical}{$identity}) {
-        $cache->{canonical}{$identity} =
-            try {
-                chomp(my $canonical = $git->run(
-                    '-c', "mailmap.file=$mailmap",
-                    'check-mailmap',
-                    $identity,
-                ));
-                $canonical;
-            } catch {
-                $git->fault(<<'EOS', {option => 'canonical'});
-The command git-check-mailmap wasn't found.
-The configuration option requires it.
-It's available since Git 1.8.4.
-Please, either upgrade your Git or disable this option.
-EOS
-                $identity;
-        };
+        chomp($cache->{canonical}{$identity} = 
+                  $git->run('-c', "mailmap.file=$mailmap", 'check-mailmap', $identity));
     }
 
     return $cache->{canonical}{$identity};
@@ -206,7 +190,16 @@ sub canonical_errors {
             my $who_name  = "${who}_name";
             my $who_email = "${who}_email";
             my $identity  = $commit->$who_name . ' <' . $commit->$who_email . '>';
-            my $canonical = _canonical_identity($git, $mailmap, $identity);
+            my $canonical = eval {_canonical_identity($git, $mailmap, $identity) };
+            unless (defined $canonical) {
+                $git->fault(<<'EOS', {option => 'canonical'});
+Git error: could not run command git-check-mailmap.
+The configuration option requires it.
+It's available since Git 1.8.4.
+Please, either upgrade your Git or disable this option.
+EOS
+                ++$errors;
+            }
 
             if ($identity ne $canonical) {
                 $git->fault(<<EOS, {commit => $commit, option => 'canonical'});
@@ -476,7 +469,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 2.9.0
+version 2.9.1
 
 =head1 SYNOPSIS
 
@@ -565,7 +558,8 @@ commit signatures.
 To enable this plugin you should add it to the githooks.plugin configuration
 option:
 
-    git config --add githooks.plugin CheckCommit
+    [githooks]
+      plugin = CheckCommit
 
 =for Pod::Coverage match_errors merge_errors email_valid_errors canonical_errors identity_errors signature_errors spelling_errors pattern_errors subject_errors body_errors footer_errors commit_errors code_errors check_pre_commit check_post_commit check_ref check_affected_refs check_patchset
 
@@ -575,13 +569,14 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 CONFIGURATION
 
-The plugin is configured by the following git options.
+The plugin is configured by the following git options under the
+C<githooks.checkcommit> subsection.
 
 It can be disabled for specific references via the C<githooks.ref> and
 C<githooks.noref> options about which you can read in the L<Git::Hooks>
 documentation.
 
-=head2 githooks.checkcommit.name [!]REGEXP
+=head2 name [!]REGEXP
 
 This multi-valued option impose restrictions on the valid author and
 committer names using regular expressions.
@@ -598,7 +593,7 @@ least a first and a last name, separated by spaces:
   [githooks "checklog"]
     name = .\\s+.
 
-=head2 githooks.checkcommit.email [!]REGEXP
+=head2 email [!]REGEXP
 
 This multi-valued option impose restrictions on the valid author and
 committer emails using regular expressions.
@@ -609,7 +604,7 @@ negative regular expressions (the ones prefixed by "!").
 
 This check is performed by the C<pre-commit> local hook.
 
-=head2 githooks.checkcommit.email-valid BOOL
+=head2 email-valid BOOL
 
 This option uses the L<Email::Valid> module' C<address> method to validate
 author and committer email addresses.
@@ -645,7 +640,7 @@ Species whether addresses must contain a fully qualified domain name
 Specifies whether a "domain literal" is acceptable as the domain part.  That
 means addresses like: C<rjbs@[1.2.3.4]>. The default is true.
 
-=head2 githooks.checkcommit.canonical MAILMAP
+=head2 canonical MAILMAP
 
 This option requires the use of canonical names and emails for authors and
 committers, as configured in a F<MAILMAP> file and checked by the
@@ -671,7 +666,7 @@ to temporarily configure it to use the F<MAILMAP> file.
 
 These checks are performed by the C<pre-commit> local hook.
 
-=head2 githooks.checkcommit.signature {nocheck|optional|good|trusted}
+=head2 signature {nocheck|optional|good|trusted}
 
 This option allows one to check commit signatures according to these values:
 
@@ -700,14 +695,14 @@ signatures.
 
 This check is performed by the C<post-commit> local hook.
 
-=head2 githooks.checkcommit.merger WHO
+=head2 merger WHO
 
 This multi-valued option restricts who can push commit merges to the
 repository. WHO may be specified as a username, a groupname, or a regex,
 like the C<githooks.admin> option (see L<Git::Hooks/CONFIGURATION>) so that
 only users matching WHO may push merge commits.
 
-=head2 githooks.checkcommit.push-limit INT
+=head2 push-limit INT
 
 This limits the number of commits that may be pushed at once on top of any
 reference. Set it to 1 to force developers to squash their commits before
@@ -715,7 +710,7 @@ pushing them. Or set it to a low number (such as 3) to deny long chains of
 commits to be pushed, which are usually made by Git newbies who don't know
 yet how to amend commits. ;-)
 
-=head2 githooks.checkcommit.check-code CODESPEC
+=head2 check-code CODESPEC
 
 If the above checks aren't enough you can use this option to define a custom
 code to check your commits. The code may be specified directly as the
