@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckReference;
 # ABSTRACT: Git::Hooks plugin for checking references
-$Git::Hooks::CheckReference::VERSION = '2.9.0';
+$Git::Hooks::CheckReference::VERSION = '2.9.1';
 use 5.010;
 use utf8;
 use strict;
@@ -133,7 +133,7 @@ Git::Hooks::CheckReference - Git::Hooks plugin for checking references
 
 =head1 VERSION
 
-version 2.9.0
+version 2.9.1
 
 =head1 SYNOPSIS
 
@@ -201,13 +201,14 @@ CheckReference - Git::Hooks plugin for checking references
 
 =head1 CONFIGURATION
 
-The plugin is configured by the following git options.
+The plugin is configured by the following git options under the
+C<githooks.checkacls> subsection.
 
 It can be disabled for specific references via the C<githooks.ref> and
 C<githooks.noref> options about which you can read in the L<Git::Hooks>
 documentation.
 
-=head2 githooks.checkreference.acl RULE
+=head2 acl RULE
 
 This multi-valued option specifies rules allowing or denying specific users to
 perform specific actions on specific references. (Common references are branches
@@ -252,13 +253,13 @@ reference namespaces for users.
 
 See the L</SYNOPSIS> section for some examples.
 
-=head2 githooks.checkreference.require-annotated-tags BOOL
+=head2 require-annotated-tags BOOL
 
 By default one can push lightweight or annotated tags but if you want to require
 that only annotated tags be pushed to the repository you can set this option to
 true.
 
-=head2 [DEPRECATED] githooks.checkreference.deny REGEXP
+=head2 [DEPRECATED] deny REGEXP
 
 This option is deprecated. Please, use an C<acl> option like this instead:
 
@@ -267,7 +268,7 @@ This option is deprecated. Please, use an C<acl> option like this instead:
 
 This directive denies references with names matching REGEXP.
 
-=head2 [DEPRECATED] githooks.checkreference.allow REGEXP
+=head2 [DEPRECATED] allow REGEXP
 
 This option is deprecated. Please, use an C<acl> option like this instead:
 
