@@ -2,14 +2,13 @@
 
 package Git::Hooks::PrepareLog;
 # ABSTRACT: Git::Hooks plugin to prepare commit messages before being edited
-$Git::Hooks::PrepareLog::VERSION = '2.9.0';
+$Git::Hooks::PrepareLog::VERSION = '2.9.1';
 use 5.010;
 use utf8;
 use strict;
 use warnings;
 use Git::Hooks;
 use Path::Tiny;
-use Carp;
 
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
 
@@ -142,7 +141,7 @@ Git::Hooks::PrepareLog - Git::Hooks plugin to prepare commit messages before bei
 
 =head1 VERSION
 
-version 2.9.0
+version 2.9.1
 
 =head1 SYNOPSIS
 
@@ -186,7 +185,8 @@ with a suitable message.
 To enable the plugin you should add it to the githooks.plugin configuration
 option:
 
-    git config --add githooks.plugin PrepareLog
+    [githooks]
+      plugin = PrepareLog
 
 =for Pod::Coverage insert_issue_in_title insert_issue_as_trailer insert_issue prepare_message
 
@@ -197,9 +197,10 @@ being edited
 
 =head1 CONFIGURATION
 
-The plugin is configured by the following git options.
+The plugin is configured by the following git options under the
+C<githooks.checkacls> subsection.
 
-=head2 githooks.preparelog.issue-branch-regex REGEX
+=head2 issue-branch-regex REGEX
 
 This option enables the issue inserting feature, which inserts an issue ID (aka
 bug-id) in the message, making the commit refer to the project issue which
@@ -235,7 +236,7 @@ understand that the issue ID is just what matched the first group in the regex.
 If your branch does not match the regex, the plugin will not prepare the log
 message.
 
-=head2 githooks.preparelog.issue-place SPEC
+=head2 issue-place SPEC
 
 This options specifies where in the log message the issue ID should be
 inserted. For now there are two possibilities which you may specify with SPECs
